# frozen_string_literal: true

module SpiritHub
  class ToClassifyController < ApplicationController
    before_action :find_models, only: %i[index sort]

    include Datatablable

    def index
      skip_authorization
      skip_policy_scope

      respond_to(&:html)
    end

    def sort
      skip_authorization
      skip_policy_scope

      render partial: 'spirit_hub/to_classify/table'
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      scope = Tagset.where(type: 'document', spirit_hubdoc: true, responsible: @user.id, parent_tagset_ids: [])
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end
