# frozen_string_literal: true

require 'faker'

FactoryBot.define do
  factory :doc_favorite, class: 'Favorite' do
    tagset do
      create(:tagset_doc, :with_state)
    end
  end

  factory :tagset_favorite, class: 'Favorite' do
    tagset do
      FactoryBot.create(:tagset_directory,
                        :complete,
                        responsible: user_id,
                        percent: [0, 25, 50, 75, 100].sample)
    end
  end

  trait :with_file do
    after(:create) do |favorite, _evaluator|
      tagset = favorite.tagset
      file_path = Rails.root.join('packages/spirit_hub/spec/fixtures/files/dog.jpg')
      uploaded_file = ActionDispatch::Http::UploadedFile.new(
        tempfile: File.open(file_path, 'rb'),
        filename: File.basename(file_path),
        type: 'application/pdf'
      )
      tagset.add_doc_to_tagset_doc(uploaded_file, tagset.responsible && User.find(tagset.responsible))

      DocPreviewWorker.new.perform(tagset.doc_ids.last)
      tagset.save
    end
  end

  trait :with_informed do
    after(:create) do |favorite, _evaluator|
      tagset = favorite.tagset

      users = FactoryBot.create_list(:user, rand(1..5))
      tagset.update(informed: users.map(&:id))
    end
  end

  trait :with_logs do
    after(:create) do |favorite|
      favorite.tagset.logs.create(action: 'Crée', user_id: favorite.user_id, data: 'hubdoc')
      20.times do
        favorite.tagset.logs.create(action: 'Modifier', user_id: favorite.user_id, data: 'hubdoc')
      end
    end
  end
end
